Buy wisely — Steph Ango
Author: Steph Ango
Description: Whenever I buy things I try to prioritize cost per use. Sometimes I consider other priorities such as cost per smile, cost per thrill, cost per externality, ...

# Buy wisely

September 30, 2023 · 5 minute read

Whenever I buy things I try to prioritize cost per use. Sometimes I consider other priorities such as cost per smile, cost per thrill, cost per externality, and cost per lesson.

## Cost per use

Considering cost per use helps me make decisions about most non-perishable purchases such as clothes, vehicles, tools, devices, and even services. How much will something cost if I divide its price by its expected number of uses?

Cost per use accounts for longevity. Durable and repairable things may cost more upfront, but over time they cost less than things that break and need to be replaced.

For example, I buy wool socks from a brand called Darn Tough. They cost about four times more than cheap socks, but they’re durable, comfortable, and have a lifetime guarantee.

How many times do you wear a pair of socks before holes appear? It may sound silly, but if you amortize the price of each pair of socks over their expected number of uses, a good pair of socks is a worthwhile investment.

Quality | Price | Uses | Cost per use
--- | --- | --- | ---
Poor | $5 | 10 | $0.50
Good | $10 | 50 | $0.20
Best | $20 | 200 | $0.10

Durable socks save you money. Durable socks save you the hassle of throwing out old socks and buying new ones. Your time has value.

The best things asymptote to zero dollars per use over their lifetime. Not all products that have a low cost per use are expensive. Some things are both affordable and durable.

Cost per use can also be used to measure the value you expect to get out of services like gym memberships, healthcare, or all-you-can-eat subscriptions like streaming services.

## How to assess durability

My aim is to have fewer but better things. These are some of the questions I ask of the things that I incorporate into my life:

- Will it be as useful to me in the future as it is now?
- Is it made of durable and maintainable materials?
- Does it have a timeless style and aesthetic?
- Does it age well, wear well, build a wabi-sabi patina?
- Does it retain its resale value? Would someone else want to own it?
- Can it be disassembled and repaired?
- Does it have replaceable, non-proprietary parts that are easy to acquire?
- Can it be powered with a standard plug or replaceable batteries?
- Can it be modified and upgraded?
- Has the maker existed for at least as long as I hope to keep the product?
- Can it perform many jobs, or only one?
- Does it have a guarantee?
- Does it rely on other products or technologies that aren’t durable?

Not all questions are relevant to all things. Not all things need to satisfy every requirement. However, I feel better about buying things that check many of these boxes. A movement called “buy it for life” has sprung up around similar priorities.

## How to estimate uses

To make purchasing decisions based on cost per use, you should try to guess how many times you will use the product. This sounds obvious, but it can be hard to determine, especially if it’s something you’ve never bought before.

If you are new to a hobby, like cooking or skiing, you may not yet know how many times you will use a piece of gear. It’s easy to significantly overestimate or underestimate how many times you will use something.

You should, however, be able to guess the frequency of use. Is this something you might use once per hour, day, week, month, year? This will help you determine your budget. How many dollars per month do you want to spend on this?

If you don’t know the frequency yet consider borrowing, renting, or otherwise trialing. Remember the ideal cost per use trends to $0. The most cost-effective choice is to not buy something you don’t need.

There is an opportunity cost to every dollar. A dollar you spend on a something that won’t get much use is a dollar you can’t save for something that will.

If you’re only going to use something once, then cost per use may not be the right heuristic for this decision. If you have disposable income, then the cost per use lens should nonetheless guide you towards something with good resale value.

The best things to splurge on are the things you use the most. If you sit on a chair eight hours a day, then a nice chair is probably a good investment.

## Reducing the cost side

Durable things reduce cost per use by giving you more uses before they break. But you can also reduce cost per use by acquiring products at a discount. You may be able to buy second-hand, inherit, or barter.

Durable things can often be great second-hand purchases because they are durable, and may not be the current fashion.

## Alternative heuristics

Cost per use is not the only way to make buying decisions. For things like consumables and experiences, you may need to approach the decision differently.

### Cost per smile

How much joy can you get out of each dollar? Some things bring lots of joy for a small amount of money: ice cream, sunsets, nature walks. A cheap date can bring many smiles per dollar.

Some things have excellent cost per use but few smiles per use. I don’t smile every time I put my nice socks on. A few years ago I bought a fairly expensive electric road bike. It probably didn’t have the best cost per use, but it gives me the most joy per use of any product I purchased in recent memory. It’s worth it to me.

### Cost per thrill

Some experiences have high intensity per dollar. A potency, concentration, or strength of experience. For example, foods can have high flavor per dollar — like hot sauce, pickles, curry, garlic, or mustard. Roller coasters, bungee jumping, or skydiving may give you a thrill per dollar that you can’t beat.

### Cost per externality

Some purchases may have externalities that are incompatible with your values. For example, you may wish to buy organic produce, pasture-raised eggs, or fair trade coffee. You may wish to buy products that preserve privacy, reduce environmental impact, or support a cause you believe in.

You can choose to incorporate externalities into the cost that you are paying instead of letting that cost be borne by others, or by society at large. This may increase your personal cost per use, but it might help change how society values things, or simply make you feel good.

### Cost per lesson

Knowledge has a cost. Sometimes that cost is monetary, sometimes that cost is time, sometimes that cost is pain. Sometimes it’s all three.

You might learn more about investing by purchasing a handful of shares in public companies than going to graduate school. You might learn more about making movies by trying to film one on your phone than going to film school.

Acquiring new ideas and perspectives can have a worthwhile cost. Being an early adopter of a product often has a poor cost per use, but its value is in the learning and experience per dollar.

Linked mentions
Quality software deserves your hard‑earned cash
Quality software is like quality food from the farmer’s market. A jar of handmade organic jam is not the same as mass-produced...

You might also enjoy

- Choose optimism
- Style is consistent constraint
- A little bit every day
- What can we remove?
- Pain is information
- Quality software deserves your hard‑earned cash
- Concise explanations accelerate progress
- Don't delegate understanding
- Caloric energy is precious